abacusai.nested_feature_schema — AbacusAI documentation

# abacusai.nested_feature_schema

## Classes

`PointInTimeFeatureInfo` | A point-in-time infos for a feature
`AbstractApiClass` |
`NestedFeatureSchema` | A schema description for a nested feature

## Module Contents

class abacusai.nested_feature_schema.PointInTimeFeatureInfo(client, expression=None, groupName=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A point-in-time infos for a feature

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - expression (str) – SQL aggregate expression which can convert a sequence of rows into a scalar value.

    - groupName (str) – The group name this point-in-time feature belongs to.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.nested_feature_schema.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.nested_feature_schema.NestedFeatureSchema(client, name=None, featureType=None, featureMapping=None, dataType=None, detectedFeatureType=None, sourceTable=None, pointInTimeInfo={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A schema description for a nested feature

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The unique name of the column

    - featureType (str) – Feature Type of the Feature

    - featureMapping (str) – The Feature Mapping of the feature

    - dataType (str) – Data Type of the Feature

    - detectedFeatureType (str) – The detected feature type for this feature

    - sourceTable (str) – The source table of the column

    - pointInTimeInfo (PointInTimeFeatureInfo) – Point in time information for this feature

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict